# This file is part of Xpra.
# Copyright (C) 2014, 2015 Antoine Martin <antoine@devloop.org.uk>
# Xpra is released under the terms of the GNU GPL v2, or, at your option, any
# later version. See the file COPYING for details.

# Printing PDF in landscape orientation does not work properly on OSX,
# so we use PS instead:
DEFAULT_MIMETYPES = "application/postscript"
